import random
import string

from datetime import datetime

from django.contrib.auth.models import User
from django.core.exceptions import ValidationError
from django.test import TestCase

from locolanderweb.models import Project, RunLog


class LocoLanderFactory(object):

    letterdigits = string.letters + string.digits

    def make_random_string(self, size=6, prefix=None):
        result = ''.join(random.choice(self.letterdigits)
                         for x in xrange(size))
        if prefix is not None:
            result = prefix + '-' + result
        return result

    def make_user(self, username=None, password='test', email=None):
        if username is None:
            username = self.make_random_string(prefix='user')
        if email is None:
            email = '%s@example.com' % username
        return User.objects.create_user(
            username=username, password=password, email=email)

    def make_project(self, user=None, url=None):
        if user is None:
            user = self.make_user()
        if url is None:
            url = 'http://foo.bar'
        return Project.objects.create(owner=user, url=url)


class BaseTestCase(TestCase):

    factory = LocoLanderFactory()


class ProjectTestCase(BaseTestCase):

    url = 'http://zaraza.foo'

    def setUp(self):
        super(ProjectTestCase, self).setUp()
        self.user = self.factory.make_user()
        self.obj = Project.objects.create(owner=self.user, url=self.url)

    def test_owner(self):
        self.assertEqual(self.obj.owner, self.user)

    def test_url(self):
        self.obj.url = 'zaraza'
        with self.assertRaises(ValidationError):
            self.obj.full_clean()

    def test_name(self):
        self.obj.name = expected = 'a' * 100
        self.obj.save()
        self.assertEqual(self.obj.name, expected)


class RunLogTestCase(BaseTestCase):

    def setUp(self):
        super(RunLogTestCase, self).setUp()
        self.project = self.factory.make_project()
        self.obj = RunLog.objects.create(project=self.project)

    def test_project(self):
        self.assertEqual(self.obj.project, self.project)

    def test_timestamp(self):
        before = datetime.utcnow()
        self.obj = RunLog.objects.create(project=self.project)
        after = datetime.utcnow()
        self.assertTrue(before <= self.obj.timestamp)
        self.assertTrue(self.obj.timestamp <= after)
