from django.core.urlresolvers import reverse

from locolanderweb.forms import ProjectForm
from locolanderweb.tests.test_models import BaseTestCase


class ProjectAddTestCase(BaseTestCase):

    password = '1234'
    url = reverse('project-add')

    def setUp(self):
        super(ProjectAddTestCase, self).setUp()
        self.user = self.factory.make_user(password=self.password)
        assert self.client.login(username=self.user.username,
                                 password=self.password)
        self.data = dict(name='foo', url='http://foo.com/')

    def test_get(self):
        assert self.user.project_set.all().count() == 0
        response = self.client.get(self.url)

        self.assertContains(response, ProjectForm(owner=self.user).as_table())
        self.assertEqual(self.user.project_set.all().count(), 0)

    def test_post(self):
        assert self.user.project_set.all().count() == 0
        response = self.client.post(self.url, data=self.data, follow=True)

        messages = [m.message for m in response.context['messages']]
        self.assertIn('Project foo added.', messages)
