from django.contrib import messages
from django.contrib.auth.decorators import login_required
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.template.response import TemplateResponse

from locolanderweb.forms import ProjectForm


@login_required
def home(request):
    context = dict(projects=request.user.project_set.all())
    return TemplateResponse(
        request, 'locolanderweb/home.html', context=context)


@login_required
def project_list(request):
    projects = request.user.project_set.all()
    return TemplateResponse(
        request, 'locolanderweb/project/list.html',
        context=dict(projects=projects))


@login_required
def project_add(request):
    if request.method == 'POST':
        form = ProjectForm(owner=request.user, data=request.POST)
        if form.is_valid():
            project = form.save()
            messages.success(request, 'Project %s added.' % project.name)
            return HttpResponseRedirect(reverse('project-list'))

        messages.error(request, 'Please correct the errors below.')
    else:
        form = ProjectForm(owner=request.user)

    return TemplateResponse(
        request, 'locolanderweb/project/add.html', context=dict(form=form))
